==> nektar%2B%2B-5.4.0.tar.xz: nektar-v5.4.0/library/FieldUtils/ProcessModules/ProcessBoundaryExtract.h <==
////////////////////////////////////////////////////////////////////////////////
//
//  File: ProcessBoundaryExtract.h
//
//  For more information, please see: http://www.nektar.info/
//
//  The MIT License
//
//  Copyright (c) 2006 Division of Applied Mathematics, Brown University (USA),
//  Department of Aeronautics, Imperial College London (UK), and Scientific
//  Computing and Imaging Institute, University of Utah (USA).
//
//  Permission is hereby granted, free of charge, to any person obtaining a
//  copy of this software and associated documentation files (the "Software"),
//  to deal in the Software without restriction, including without limitation
//  the rights to use, copy, modify, merge, publish, distribute, sublicense,
//  and/or sell copies of the Software, and to permit persons to whom the
//  Software is furnished to do so, subject to the following conditions:
//
//  The above copyright notice and this permission notice shall be included
//  in all copies or substantial portions of the Software.
//
//  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
//  OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
//  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
//  THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
//  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
//  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
//  DEALINGS IN THE SOFTWARE.
//
//  Description: Process Boundary field extraction
//
////////////////////////////////////////////////////////////////////////////////

#ifndef FIELDUTILS_PROCESSBOUNDARYEXTRACT
#define FIELDUTILS_PROCESSBOUNDARYEXTRACT

#include "../Module.h"

namespace Nektar
{
namespace FieldUtils
{

/**
 * @brief This processing module sets up for the boundary field to be extracted
 */
class ProcessBoundaryExtract : public ProcessModule
{
public:
    /// Creates an instance of this class
    static std::shared_ptr<Module> create(FieldSharedPtr f)
    {
        return MemoryManager<ProcessBoundaryExtract>::AllocateSharedPtr(f);
    }
    static ModuleKey className;

    ProcessBoundaryExtract(FieldSharedPtr f);
    virtual ~ProcessBoundaryExtract();

protected:
    virtual void v_Process(po::variables_map &vm) override;

    virtual std::string v_GetModuleName() override
    {
        return "ProcessBoundaryExtract";
    }

    virtual std::string v_GetModuleDescription() override
    {
        return "Setting up boundary extraction";
    }

    virtual ModulePriority v_GetModulePriority() override
    {
        return eBndExtraction;
    }
};
} // namespace FieldUtils
} // namespace Nektar

#endif

==> nektar%2B%2B-5.8.0.tar.xz: nektar-v5.8.0/library/FieldUtils/ProcessModules/ProcessBoundaryExtract.h <==
////////////////////////////////////////////////////////////////////////////////
//
//  File: ProcessBoundaryExtract.h
//
//  For more information, please see: http://www.nektar.info/
//
//  The MIT License
//
//  Copyright (c) 2006 Division of Applied Mathematics, Brown University (USA),
//  Department of Aeronautics, Imperial College London (UK), and Scientific
//  Computing and Imaging Institute, University of Utah (USA).
//
//  Permission is hereby granted, free of charge, to any person obtaining a
//  copy of this software and associated documentation files (the "Software"),
//  to deal in the Software without restriction, including without limitation
//  the rights to use, copy, modify, merge, publish, distribute, sublicense,
//  and/or sell copies of the Software, and to permit persons to whom the
//  Software is furnished to do so, subject to the following conditions:
//
//  The above copyright notice and this permission notice shall be included
//  in all copies or substantial portions of the Software.
//
//  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
//  OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
//  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
//  THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
//  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
//  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
//  DEALINGS IN THE SOFTWARE.
//
//  Description: Process Boundary field extraction
//
////////////////////////////////////////////////////////////////////////////////

#ifndef FIELDUTILS_PROCESSBOUNDARYEXTRACT
#define FIELDUTILS_PROCESSBOUNDARYEXTRACT

#include "../Module.h"

namespace Nektar::FieldUtils
{

/**
 * @brief This processing module sets up for the boundary field to be extracted
 */
class ProcessBoundaryExtract : public ProcessModule
{
public:
    /// Creates an instance of this class
    static std::shared_ptr<Module> create(FieldSharedPtr f)
    {
        return MemoryManager<ProcessBoundaryExtract>::AllocateSharedPtr(f);
    }
    static ModuleKey className;

    ProcessBoundaryExtract(FieldSharedPtr f);
    ~ProcessBoundaryExtract() override;

protected:
    void v_Process(po::variables_map &vm) override;

    std::string v_GetModuleName() override
    {
        return "ProcessBoundaryExtract";
    }

    std::string v_GetModuleDescription() override
    {
        return "Setting up boundary extraction";
    }

    ModulePriority v_GetModulePriority() override
    {
        return eBndExtraction;
    }
};
} // namespace Nektar::FieldUtils

#endif
